@@ -19,7 +19,6 @@ use Psr\EventDispatcher\EventDispatcherInterface;
 use Psr\Http\Message\ServerRequestInterface;
 use TYPO3\CMS\Backend\Clipboard\Clipboard;
 use TYPO3\CMS\Backend\Configuration\TranslationConfigurationProvider;
-use TYPO3\CMS\Backend\ElementBrowser\Event\IsFileSelectableEvent;
 use TYPO3\CMS\Backend\Routing\Route;
 use TYPO3\CMS\Backend\Routing\UriBuilder;
 use TYPO3\CMS\Backend\Template\Components\Buttons\ButtonInterface;
@@ -66,6 +65,7 @@ use TYPO3\CMS\Filelist\Matcher\ResourceFolderTypeMatcher;
 use TYPO3\CMS\Filelist\Pagination\ResourceCollectionPaginator;
 use TYPO3\CMS\Filelist\Type\Mode;
 use TYPO3\CMS\Filelist\Type\NavigationDirection;
+use TYPO3\CMS\Filelist\Type\SortDirection;
 use TYPO3\CMS\Filelist\Type\ViewMode;
 
 /**
@@ -101,13 +101,18 @@ class FileList
     /**
      * The field to sort by
      */
-    public string $sort = '';
+    public string $sortField = '';
 
     /**
      * Reverse sorting flag
+     * This option is kept for backwards compatibility reasons and removed in TYPO3 v14.
+     *
+     * @deprecated
      */
     public bool $sortRev = true;
 
+    public SortDirection $sortDirection = SortDirection::DESCENDING;
+
     /**
      * Thumbnails on records containing files (pictures)
      */
@@ -233,16 +238,22 @@ class FileList
      *
      * @param Folder $folderObject The folder to work on
      * @param int $currentPage The current page to render
-     * @param string $sort Sorting column
-     * @param bool $sortRev Sorting direction
+     * @param string $sortField Sorting column
+     * @param bool|SortDirection $sortDirection Sorting direction
      * @param Mode $mode Mode of the file list
      */
-    public function start(Folder $folderObject, int $currentPage, string $sort, bool $sortRev, Mode $mode = Mode::MANAGE)
+    public function start(Folder $folderObject, int $currentPage, string $sortField, bool|SortDirection $sortDirection, Mode $mode = Mode::MANAGE)
     {
         $this->folderObject = $folderObject;
         $this->currentPage = MathUtility::forceIntegerInRange($currentPage, 1, 100000);
-        $this->sort = $sort;
-        $this->sortRev = $sortRev;
+        $this->sortField = $sortField;
+        if (is_bool($sortDirection)) {
+            $this->sortRev = $sortDirection;
+            $this->sortDirection =  $sortDirection ? SortDirection::DESCENDING : SortDirection::ASCENDING;
+        } else {
+            $this->sortRev = $sortDirection === SortDirection::DESCENDING;
+            $this->sortDirection = $sortDirection;
+        }
         $this->totalbytes = 0;
         $this->resourceDownloadMatcher = null;
         $this->resourceDisplayMatcher = null;
@@ -337,8 +348,8 @@ class FileList
         $this->totalbytes = $resourceCollection->getTotalBytes();
 
         // Sort the files before sending it to the renderer
-        if (trim($this->sort) !== '') {
-            $resourceCollection->setResources($this->sortResources($resourceCollection->getResources(), $this->sort));
+        if (trim($this->sortField) !== '') {
+            $resourceCollection->setResources($this->sortResources($resourceCollection->getResources(), $this->sortField));
         }
 
         $paginator = new ResourceCollectionPaginator($resourceCollection, $this->currentPage, $this->itemsPerPage);
@@ -359,9 +370,6 @@ class FileList
 
             $resourceView->isDownloadable = $this->resourceDownloadMatcher !== null && $this->resourceDownloadMatcher->match($resource);
             $resourceView->isSelectable = $this->resourceSelectableMatcher !== null && $this->resourceSelectableMatcher->match($resource);
-            if ($this->mode === Mode::BROWSE && $resource instanceof File) {
-                $resourceView->isSelectable = $this->eventDispatcher->dispatch(new IsFileSelectableEvent($resource))->isFileSelectable();
-            }
             $resourceView->isSelected = $this->resourceSelectedMatcher !== null && $this->resourceSelectedMatcher->match($resource);
 
             $resourceViews[] = $resourceView;
@@ -428,54 +436,61 @@ class FileList
         );
     }
 
+    /**
+     * @return array<string>
+     */
+    public function getSortableFields(): array
+    {
+        return array_filter($this->fieldArray, $this->isFieldSortable(...));
+    }
+
     protected function renderListTableHeader(): string
     {
         $data = [];
         foreach ($this->fieldArray as $field) {
-            switch ($field) {
-                case 'icon':
-                    $data[$field] = '';
-                    break;
-                case '_SELECTOR_':
-                    $data[$field] = $this->renderCheckboxActions();
-                    break;
-                default:
-                    $data[$field] = $this->renderListTableFieldHeader($field);
-                    break;
-            }
+            $data[$field] = match ($field) {
+                'icon' => '',
+                '_SELECTOR_' => $this->renderCheckboxActions(),
+                default => $this->renderListTableFieldHeader($field),
+            };
         }
 
         return $this->addElement($data, [], true);
     }
 
+    protected function isFieldSortable(string $field): bool
+    {
+        return !in_array($field, ['icon', 'rw', '_SELECTOR_', '_CONTROL_', '_PATH_'], true);
+    }
+
     protected function renderListTableFieldHeader(string $field): string
     {
         $label = $this->getFieldLabel($field);
-        if (in_array($field, ['_SELECTOR_', '_CONTROL_', '_PATH_'])) {
+        if (!$this->isFieldSortable($field)) {
             return $label;
         }
 
-        $params = ['sort' => $field, 'currentPage' => 0];
+        $params = ['sortField' => $field, 'currentPage' => 0];
         $paramsAsc = $params;
-        $paramsAsc['reverse'] = 0;
+        $paramsAsc['sortDirection'] = SortDirection::ASCENDING->value;
         $paramsDesc = $params;
-        $paramsDesc['reverse'] = 1;
+        $paramsDesc['sortDirection'] = SortDirection::DESCENDING->value;
 
-        $icon = $this->sort === $field
-            ? $this->iconFactory->getIcon('actions-sort-amount-' . ($this->sortRev ? 'down' : 'up'), IconSize::SMALL)->render()
+        $icon = $this->sortField === $field
+            ? $this->iconFactory->getIcon($this->sortDirection->getIconIdentifier(), IconSize::SMALL)->render()
             : $this->iconFactory->getIcon('empty-empty', IconSize::SMALL)->render();
 
         return '
             <div class="dropdown dropdown-static">
                 <button class="dropdown-toggle dropdown-toggle-link" type="button" data-bs-toggle="dropdown" aria-expanded="false">
-                    ' . htmlspecialchars($label) . ' <div class="' . ($this->sort === $field ? 'text-primary' : '') . '">' . $icon . '</div>
+                    ' . htmlspecialchars($label) . ' <div class="' . ($this->sortField === $field ? 'text-primary' : '') . '">' . $icon . '</div>
                 </button>
                 <ul class="dropdown-menu">
                     <li>
                         <a href="' . $this->createModuleUri($paramsAsc) . '" class="dropdown-item">
                             <span class="dropdown-item-columns">
                                 <span class="dropdown-item-column dropdown-item-column-icon text-primary">
-                                    ' . ($this->sort === $field && !$this->sortRev ? $this->iconFactory->getIcon('actions-dot', IconSize::SMALL)->render() : '') . '
+                                    ' . ($this->sortField === $field && $this->sortDirection === SortDirection::ASCENDING ? $this->iconFactory->getIcon('actions-dot', IconSize::SMALL)->render() : '') . '
                                 </span>
                                 <span class="dropdown-item-column dropdown-item-column-title">
                                     ' . $this->getLanguageService()->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:labels.sorting.asc') . '
@@ -487,7 +502,7 @@ class FileList
                         <a href="' . $this->createModuleUri($paramsDesc) . '" class="dropdown-item">
                             <span class="dropdown-item-columns">
                                 <span class="dropdown-item-column dropdown-item-column-icon text-primary">
-                                    ' . ($this->sort === $field && $this->sortRev ? $this->iconFactory->getIcon('actions-dot', IconSize::SMALL)->render() : '') . '
+                                    ' . ($this->sortField === $field && $this->sortDirection === SortDirection::DESCENDING ? $this->iconFactory->getIcon('actions-dot', IconSize::SMALL)->render() : '') . '
                                 </span>
                                 <span class="dropdown-item-column dropdown-item-column-title">
                                     ' . $this->getLanguageService()->sL('LLL:EXT:core/Resources/Private/Language/locallang_core.xlf:labels.sorting.desc') . '
@@ -515,7 +530,7 @@ class FileList
                 'data-filelist-identifier' => $resourceView->getIdentifier(),
                 'data-filelist-name' => htmlspecialchars($resourceView->getName()),
                 'data-filelist-icon' => $resourceView->getIconIdentifier(),
-                'data-filelist-thumbnail' => $resourceView->getThumbnailUri(),
+                'data-filelist-preview' => $resourceView->getPreview() !== null ? 'true' : 'false',
                 'data-filelist-uid' => $resourceView->getUid(),
                 'data-filelist-meta-uid' => $resourceView->getMetaDataUid(),
                 'data-filelist-url' => $resourceView->getPublicUrl(),
@@ -664,11 +679,7 @@ class FileList
         $attributes['title'] = $resourceView->getName();
         $attributes['type'] = 'button';
         $attributes['class'] = 'btn btn-link';
-        if ($resourceView->isSelectable) {
-            $attributes['data-filelist-action'] = 'primary';
-        } else {
-            $attributes['disabled'] = true;
-        }
+        $attributes['data-filelist-action'] = 'primary';
 
         $output = '<button ' . GeneralUtility::implodeAttributes($attributes, true) . '>' . $resourceName . '</button>';
         if ($resourceView->isMissing()) {
@@ -1665,7 +1676,7 @@ class FileList
         $collator = new \Collator((string)($this->getLanguageService()->getLocale() ?? 'en'));
         $collator->setAttribute(\Collator::NUMERIC_COLLATION, \Collator::ON);
 
-        $sortMultiplier = $this->sortRev ? -1 : 1;
+        $sortMultiplier = $this->sortDirection === SortDirection::DESCENDING ? -1 : 1;
         uksort($resources, function (int $index1, int $index2) use ($sortField, $sortMultiplier, $resources, $collator) {
             $resource1 = $resources[$index1];
             $resource2 = $resources[$index2];
@@ -1746,7 +1757,7 @@ class FileList
         }
     }
 
-    protected function getFieldLabel(string $field): string
+    public function getFieldLabel(string $field): string
     {
         $lang = $this->getLanguageService();
 
